--[[
IncreasedWorkAreasForPickups

Specialization for wider work areas on pickups, so it is easier to pick up the windrows, especially on turns

Author: 	Ifko[nator]
Date: 		03.01.2024
Version:	1.0

History:	v1.0 @03.01.2024 - initial implementation in FS 22
]]

IncreasedWorkAreasForPickups = {};

IncreasedWorkAreasForPickups.modDirectory = g_currentModDirectory;

function IncreasedWorkAreasForPickups:workAreaOnLoad(savegame)
	local modDesc = loadXMLFile("modDesc", IncreasedWorkAreasForPickups.modDirectory .. "modDesc.xml");

	local workingWidth = MathUtil.round(Utils.getNoNil(getXMLFloat(modDesc, "modDesc.increasedWorkAreasForPickups#workingWidth"), 4) / 2, 2);

	delete(modDesc);

	for _, workArea in pairs(self.spec_workArea.workAreas) do
		if workArea.functionName == "processPickupCutterArea" --## forage harvester pickup
			or workArea.functionName == "processForageWagonArea" --## forage wagon
			or workArea.functionName == "processBalerArea" --## baler
		then	
			local _, workAreaStartY, workAreaStartZ = getTranslation(workArea.start);
			local _, _, workAreaHeightZ = getTranslation(workArea.height);

			setTranslation(workArea.start, workingWidth, workAreaStartY, workAreaStartZ);
			setTranslation(workArea.width, -workingWidth, workAreaStartY, workAreaStartZ);
			setTranslation(workArea.height, workingWidth, workAreaStartY, workAreaHeightZ);

			workArea.groundReferenceNode.threshold = 5;
		end;
	end;
end;

WorkArea.onLoad = Utils.appendedFunction(WorkArea.onLoad, IncreasedWorkAreasForPickups.workAreaOnLoad);